==> neo4j-primitive-collections-3.1.6-sources.jar: org/neo4j/collection/primitive/PrimitiveLongPeekingIterator.java <==
/*
 * Copyright (c) 2002-2017 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.collection.primitive;

public class PrimitiveLongPeekingIterator extends PrimitiveLongCollections.PrimitiveLongBaseIterator
{
    private final PrimitiveLongIterator actual;
    private long firstValue;
    private boolean hasFirstValue;
    private boolean hasMultipleValues;

    public PrimitiveLongPeekingIterator( PrimitiveLongIterator actual )
    {
        this.actual = actual;
        if ( actual.hasNext() )
        {
            firstValue = actual.next();
            hasFirstValue = true;
            hasMultipleValues = actual.hasNext();
        }
    }

    @Override
    protected boolean fetchNext()
    {
        if ( hasFirstValue )
        {
            hasFirstValue = false;
            return next( firstValue );
        }
        return actual.hasNext() ? next( actual.next() ) : false;
    }

    public boolean hasMultipleValues()
    {
        return hasMultipleValues;
    }
}

==> neo4j-primitive-collections-3.3.1-sources.jar: org/neo4j/collection/primitive/PrimitiveLongPeekingIterator.java <==
/*
 * Copyright (c) 2002-2017 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.collection.primitive;

public class PrimitiveLongPeekingIterator extends PrimitiveLongCollections.PrimitiveLongBaseIterator
{
    private final PrimitiveLongIterator actual;
    private long firstValue;
    private boolean hasFirstValue;
    private boolean hasMultipleValues;

    public PrimitiveLongPeekingIterator( PrimitiveLongIterator actual )
    {
        this.actual = actual;
        if ( actual.hasNext() )
        {
            firstValue = actual.next();
            hasFirstValue = true;
            hasMultipleValues = actual.hasNext();
        }
    }

    @Override
    protected boolean fetchNext()
    {
        if ( hasFirstValue )
        {
            hasFirstValue = false;
            return next( firstValue );
        }
        return actual.hasNext() && next( actual.next() );
    }

    public boolean hasMultipleValues()
    {
        return hasMultipleValues;
    }
}
